- David Glick - Original Author
- Adam Forsythe-Cheasley - Documentation/Testing
- Ben Cole - Documentation/Testing
- Matthew Sital-Singh - Documentation
- Paul Grunewald - German translation
- Cillian De Róiste
- Wolfgang Thomas
- Alessandro Pisa
